@@ -17,16 +17,10 @@ void* DecodeEthernet(int PacketSlot){
 	EthernetData*	data;
 	PacketRec*		p;
 	
-#ifdef DEBUGPATH
-	printf("In DecodeEthernet\n");
-#endif
+	DEBUGPATH;
 
 	p=&Globals.Packets[PacketSlot];
 
-#ifdef DEBUG
-	printf("Decoding Ethernet Header\n");
-#endif
-
 	/*grab the interface to check the type*/
 	/*The interface record is always the first on the stack*/
 	r=((InterfaceData*)(p->DecoderInfo[0].Data))->r;
@@ -51,9 +45,7 @@ void* DecodeEthernet(int PacketSlot){
 int InitDecoderEthernet(){
 	int DecoderID;
 
-#ifdef DEBUGPATH
-	printf("In InitDecoderEthernet\n");
-#endif
+	DEBUGPATH;
 	
 	if ((DecoderID=CreateDecoder("Ethernet"))==DECODER_NONE){
 #ifdef DEBUG
@@ -63,6 +55,7 @@ int InitDecoderEthernet(){
 	}
 	
 	Globals.Decoders[DecoderID].DecodeFunc=DecodeEthernet;
+	Globals.Decoders[DecoderID].Free=free;
 	if (!DecoderAddDecoder(GetDecoderByName("Interface"), DecoderID)){
 		printf("Failed to Bind Ethernet Decoder to Interface Decoder\n");
 		return FALSE;
