@@ -20,13 +20,7 @@ void* DecodeICMP(int PacketSlot){
 	unsigned char	ip_proto;
 	PacketRec*		p;
 	
-#ifdef DEBUGPATH
-	printf("In DecodeICMP\n");
-#endif
-
-#ifdef DEBUG
-	printf("Decoding ICMP Header\n");
-#endif
+	DEBUGPATH;
 
 	p=&Globals.Packets[PacketSlot];
 
@@ -61,9 +55,7 @@ void* DecodeICMP(int PacketSlot){
 int InitDecoderICMP(){
 	int DecoderID;
 
-#ifdef DEBUGPATH
-	printf("In InitDecoderICMP\n");
-#endif
+	DEBUGPATH;
 	
 	if ((DecoderID=CreateDecoder("ICMP"))==DECODER_NONE){
 #ifdef DEBUG
@@ -73,6 +65,7 @@ int InitDecoderICMP(){
 	}
 	
 	Globals.Decoders[DecoderID].DecodeFunc=DecodeICMP;
+	Globals.Decoders[DecoderID].Free=free;
 	if (!DecoderAddDecoder(GetDecoderByName("IP"), DecoderID)){
 		printf("Failed to Bind ICMP Decoder to IPDefrag Decoder\n");
 		return FALSE;
