@@ -15,20 +15,22 @@
 * harness for the packet caching system.
 ***********************************************/
 
-extern GlobalVars		Globals;
+extern GlobalVars	Globals;
 
-int				IPDecoderID;
-Cache*				FragCache;
-pthread_mutex_t			FragMutex;
-int				FragLockID;
+int			IPDecoderID;
+int			IPDefragDecoderID;
+
+Cache*			FragCache;
+pthread_mutex_t		FragMutex;
+int			FragLockID;
 
 struct defrag_item{
-	int			begin;
-	int			end;
-	int			PacketSlot;
-	IPData*			idata;
-	int			more;
-	char			done;
+	int		begin;
+	int		end;
+	int		PacketSlot;
+	IPData*		idata;
+	int		more;
+	char		done;
 };
 
 /************************************************************************
@@ -254,6 +256,28 @@ int SortFragArray(struct defrag_item* Frags, int NumFrags){
 	return TRUE;
 }
 
+void IPDefragCacheFreeFunction (void *pointer) {
+	int PacketSlot = *(int*)pointer;
+
+	DEBUGPATH;
+
+	if (Globals.Packets[PacketSlot].DecoderInfo[IPDefragDecoderID].Data)
+		if (((IPDefragData *)Globals.Packets[PacketSlot].DecoderInfo[IPDefragDecoderID].Data)->IsRebuilt)
+			return;
+
+	#ifdef DEBUG
+	printf("Returning slot %i\n", PacketSlot);
+	#endif
+
+	Globals.Packets[PacketSlot].SaveCount--;
+
+	#ifdef DEBUG
+	printf("SaveCount is now %i\n",Globals.Packets[PacketSlot].SaveCount);
+	#endif
+
+	ReturnEmptyPacket(*(int*)pointer);
+}
+
 /***************************************
 * Reassemble fragmented ip packets
 ****************************************/
@@ -288,6 +312,10 @@ void* DecodeIPDefrag(int PacketSlot){
 
 	p = &Globals.Packets[PacketSlot];
 
+	hlbr_mutex_lock(&FragMutex, FRAG_LOCK_1, &FragLockID);
+	CacheTimeout(FragCache, time(NULL));
+	hlbr_mutex_unlock(&FragMutex);
+
 	if (!GetDataByID(PacketSlot, IPDecoderID, (void**)&idata)){
 		printf("Failed to get ip header data\n");
 		return NULL;
@@ -385,23 +413,10 @@ void* DecodeIPDefrag(int PacketSlot){
 				/*tell the engine we're done with these packets*/
 				PacketRec* newp = RebuildPacket(Frags, NumFrags);
 
-				for (i=0;i<CI->NumItems;i++){
-					if (*(int*)CI->Items[i].Data == PacketSlot)
-						continue;
-#ifdef DEBUG
-					printf("Returning slot %i\n",*(int*)CI->Items[i].Data);
-#endif
-					Globals.Packets[*(int*)CI->Items[i].Data].SaveCount--;
-#ifdef DEBUG
-					printf("SaveCount is now %i\n",Globals.Packets[*(int*)CI->Items[i].Data].SaveCount);
-#endif
-					ReturnEmptyPacket(*(int*)CI->Items[i].Data);
-				}
-
-				CacheDelKey(FragCache, (unsigned char*)&Key, sizeof(struct defrag_key), Globals.Packets[PacketSlot].tv.tv_sec);
-
 				if (!newp){
+					CacheDelKey(FragCache, (unsigned char*)&Key, sizeof(struct defrag_key), Globals.Packets[PacketSlot].tv.tv_sec);
 					hlbr_mutex_unlock(&FragMutex);
+
 					return NULL;
 				}
 
@@ -416,7 +431,7 @@ void* DecodeIPDefrag(int PacketSlot){
 #ifdef DEBUG
 				printf("Packet was rebuilt\n");
 #endif
-				data=calloc(sizeof(IPDefragData),1);
+				data = calloc(sizeof(IPDefragData),1);
 
 				if (!data){
 					hlbr_mutex_unlock(&FragMutex);
@@ -424,6 +439,10 @@ void* DecodeIPDefrag(int PacketSlot){
 				}
 
 				data->IsRebuilt=TRUE;
+
+				Globals.Packets[PacketSlot].DecoderInfo[IPDefragDecoderID].Data = data;
+
+				CacheDelKey(FragCache, (unsigned char*)&Key, sizeof(struct defrag_key), Globals.Packets[PacketSlot].tv.tv_sec);
 			}
 		}else{
 #ifdef DEBUG
@@ -453,27 +472,26 @@ void* DecodeIPDefrag(int PacketSlot){
 * Set up the decoder
 *************************************/
 int InitDecoderIPDefrag(){
-	int DecoderID;
-
 	DEBUGPATH;
 
-	if ((DecoderID=CreateDecoder("IPDefrag"))==DECODER_NONE){
+	if ((IPDefragDecoderID = CreateDecoder("IPDefrag")) == DECODER_NONE){
 #ifdef DEBUG
 		printf("Couldn't Allocate IP Defrag Decoder\n");
 #endif
 		return FALSE;
 	}
 
-	Globals.Decoders[DecoderID].DecodeFunc=DecodeIPDefrag;
-	Globals.Decoders[DecoderID].Free=free;
-	if (!DecoderAddDecoder(GetDecoderByName("IP"), DecoderID)){
+	Globals.Decoders[IPDefragDecoderID].DecodeFunc = DecodeIPDefrag;
+	Globals.Decoders[IPDefragDecoderID].Free = free;
+
+	if (!DecoderAddDecoder(GetDecoderByName("IP"), IPDefragDecoderID)){
 		printf("Failed to Bind IP Defrag Decoder to IP Decoder\n");
 		return FALSE;
 	}
 
-	IPDecoderID=GetDecoderByName("IP");
+	IPDecoderID = GetDecoderByName("IP");
 
-	FragCache = InitCache(FRAG_TIMEOUT);
+	FragCache = InitCache(FRAG_TIMEOUT, IPDefragCacheFreeFunction);
 
 	return TRUE;
 }
