@@ -8,14 +8,15 @@
 /***************************************
 * Set up a new cache
 ***************************************/
-Cache* InitCache(int TimeoutLen){
+Cache* InitCache(int TimeoutLen, void (*Free)(void *)){
 	Cache*		NewCache;
-	
+
 	DEBUGPATH;
-	
-	NewCache=calloc(sizeof(Cache),1);
-	NewCache->TimeoutLen=TimeoutLen;
-	
+
+	NewCache = calloc(sizeof(Cache),1);
+	NewCache->TimeoutLen = TimeoutLen;
+	NewCache->Free = Free;
+
 	return NewCache;
 }
 
@@ -24,19 +25,19 @@ Cache* InitCache(int TimeoutLen){
 **********************************************/
 int CacheGetBin(Cache* c, unsigned char* Key, int KeyLen){
 	int		i;
-	
+
 #ifdef DEBGUPATH
 	printf("In CacheGetBin\n");
 #endif
 
-	for (i=0;i<c->NumKeys;i++){
-		if (c->Keys[i].KeyLen==KeyLen){
+	for (i = 0 ; i < c->NumKeys ; i++){
+		if (c->Keys[i].KeyLen == KeyLen){
 			if (memcmp(c->Keys[i].Key, Key, KeyLen)==0){
 				return i;
 			}
 		}
 	}
-	
+
 	return CACHE_NONE;
 }
 
@@ -44,26 +45,23 @@ int CacheGetBin(Cache* c, unsigned char* Key, int KeyLen){
 * Create a new bin to put stuff in
 *********************************************/
 int CacheCreateBin(Cache* c, unsigned char* Key, int KeyLen){
-
-  DEBUGPATH;
+	DEBUGPATH;
 
 	/*check to see if we're full*/
-	if (c->NumKeys>=CACHE_MAX_KEYS){
-#ifdef DEBUG	
+	if (c->NumKeys >= CACHE_MAX_KEYS){
+#ifdef DEBUG
 		printf("Cache is full\n");
-#endif		
+#endif
 		return CACHE_NONE;
 	}
 
 	/*allocate a new one*/
-	c->Keys[c->NumKeys].Key=malloc(KeyLen);
+	c->Keys[c->NumKeys].Key = malloc(KeyLen);
 	memcpy(c->Keys[c->NumKeys].Key, Key, KeyLen);
-	c->Keys[c->NumKeys].KeyLen=KeyLen;
-	c->Keys[c->NumKeys].NumItems=0;
+	c->Keys[c->NumKeys].KeyLen = KeyLen;
+	c->Keys[c->NumKeys].NumItems = 0;
 
-	c->NumKeys++;
-	
-	return c->NumKeys-1;
+	return c->NumKeys++;
 }
 
 
@@ -71,22 +69,21 @@ int CacheCreateBin(Cache* c, unsigned char* Key, int KeyLen){
 * put a new item in a cache bin
 *********************************************/
 int CacheBinAdd(CacheItems* ci, unsigned char* Data, int DataLen){
+	DEBUGPATH;
 
-  DEBUGPATH;
-
-	if (ci->NumItems==CACHE_MAX_ITEMS_PER_KEY){
+	if (ci->NumItems == CACHE_MAX_ITEMS_PER_KEY){
 #ifdef DEBUG
 		printf("This key if full\n");
-#endif	
+#endif
 		return FALSE;
 	}
-	
-	ci->Items[ci->NumItems].Data=malloc(DataLen);
+
+	ci->Items[ci->NumItems].Data = malloc(DataLen);
 	memcpy(ci->Items[ci->NumItems].Data, Data, DataLen);
-	ci->Items[ci->NumItems].DataLen=DataLen;
-	
+	ci->Items[ci->NumItems].DataLen = DataLen;
+
 	ci->NumItems++;
-		
+
 	return TRUE;
 }
 
@@ -94,7 +91,7 @@ int CacheBinAdd(CacheItems* ci, unsigned char* Data, int DataLen){
 * Kill any keys that have timed out
 ************************************************/
 void CacheTimeout(Cache* c, int Now){
-	int		i;
+	int	i;
 	
 	DEBUGPATH;
 
@@ -111,21 +108,21 @@ void CacheTimeout(Cache* c, int Now){
 *********************************************/
 int CacheAdd(Cache* c, unsigned char* Key, int KeyLen, unsigned char* Data, int DataLen, int Now){
 	int	BinID;
-	
+
 	DEBUGPATH;
 
 	/*go find the bin, if it exists*/
-	BinID=CacheGetBin(c, Key, KeyLen);
-	if (BinID==CACHE_NONE){
+	BinID = CacheGetBin(c, Key, KeyLen);
+	if (BinID == CACHE_NONE){
 #ifdef DEBUG
 		printf("First Item in this bin\n");
 #endif
-		BinID=CacheCreateBin(c, Key, KeyLen);		
+		BinID = CacheCreateBin(c, Key, KeyLen);
 	}
-	if (BinID==CACHE_NONE){
+	if (BinID == CACHE_NONE){
 #ifdef DEBUG
 		printf("Failed to create a new bin\n");
-#endif	
+#endif
 		return FALSE;
 	}
 
@@ -133,13 +130,14 @@ int CacheAdd(Cache* c, unsigned char* Key, int KeyLen, unsigned char* Data, int
 	if (!CacheBinAdd(&c->Keys[BinID], Data, DataLen)){
 #ifdef DEBUG
 		printf("Failed to add to key. full?\n");
-#endif	
+#endif
 		return FALSE;
 	}
-	c->Keys[BinID].LastTime=Now;
+
+	c->Keys[BinID].LastTime = Now;
 
 	CacheTimeout(c, Now);
-		
+
 	return TRUE;
 }
 
@@ -147,42 +145,46 @@ int CacheAdd(Cache* c, unsigned char* Key, int KeyLen, unsigned char* Data, int
 * We're done with this key, kill it
 *************************************************/
 int CacheDelKey(Cache* c, unsigned char* Key, int KeyLen, int Now){
-	int			KeyID;
-	int			i;
+	int		KeyID;
+	int		i;
 	CacheItems*	ci;
-	
+
 	DEBUGPATH;
 
 	/*go find the bin*/
-	KeyID=CacheGetBin(c, Key, KeyLen);
-	if (KeyID==CACHE_NONE){
+	KeyID = CacheGetBin(c, Key, KeyLen);
+	if (KeyID == CACHE_NONE){
 #ifdef DEBUG
 		printf("There is no such key\n");
 #endif	
 		return FALSE;
 	}
-	
+
 	/*get rid of the items in that bin*/
 	ci = &c->Keys[KeyID];
-	for (i=0;i<ci->NumItems;i++){
-		if (ci->Items[i].Data) free(ci->Items[i].Data);
-		ci->Items[i].Data=NULL;
-		ci->Items[i].DataLen=0;
+	for (i = 0 ; i < ci->NumItems ; i++){
+		if (ci->Items[i].Data)
+			c->Free (ci->Items[i].Data);
+
+		ci->Items[i].Data = NULL;
+		ci->Items[i].DataLen = 0;
 	}
-	
+
 	/*get rid of the bin*/
-	if (ci->Key) free(ci->Key);
-	ci->Key=NULL;
-	ci->KeyLen=0;
-	ci->NumItems=0;
-	
+	if (ci->Key)
+		free(ci->Key);
+
+	ci->Key = NULL;
+	ci->KeyLen = 0;
+	ci->NumItems = 0;
+
 	/*move everything up*/
 	memcpy(&c->Keys[KeyID], &c->Keys[KeyID+1], sizeof(CacheItems) * (c->NumKeys-KeyID));
 	c->NumKeys--;
-	
+
 	CacheTimeout(c, Now);
-		
-	return TRUE;	
+
+	return TRUE;
 }
 
 /********************************************
@@ -190,19 +192,19 @@ int CacheDelKey(Cache* c, unsigned char* Key, int KeyLen, int Now){
 ********************************************/
 CacheItems* CacheGet(Cache* c, unsigned char* Key, int KeyLen, int Now){
 	int	KeyID;
-	
+
 	DEBUGPATH;
 
-	KeyID=CacheGetBin(c, Key, KeyLen);
-	if (KeyID==CACHE_NONE){
+	KeyID = CacheGetBin(c, Key, KeyLen);
+	if (KeyID == CACHE_NONE){
 #ifdef DEBUG
 		printf("No Such key\n");
-#endif	
+#endif
 		return NULL;
 	}
-	
+
 	CacheTimeout(c, Now);
-	
+
 	return &c->Keys[KeyID];
 }
 
@@ -214,13 +216,16 @@ void DestroyCache(Cache* c){
 
 	DEBUGPATH;
 
-	for (i=0;i<c->NumKeys;i++){
-		for (j=0;j<c->Keys[i].NumItems;j++){
-			if (c->Keys[i].Items[j].Data) free(c->Keys[i].Items[j].Data);
+	for (i = 0 ; i < c->NumKeys ; i++){
+		for (j = 0 ; j < c->Keys[i].NumItems ; j++){
+			if (c->Keys[i].Items[j].Data)
+				c->Free (c->Keys[i].Items[j].Data);
 		}
-		if (c->Keys[i].Key) free(c->Keys[i].Key);
+
+		if (c->Keys[i].Key)
+			free(c->Keys[i].Key);
 	}
-	
+
 	free(c);
-	c=NULL;
+	c = NULL;
 }
