@@ -1,3 +1,7 @@
+//#define DEBUGBUILD
+//#define DEBUGMATCH
+//#define DEBUGFINAL
+//#define DEBUGESCAPE
 /**************************************
 * This is a multi-string matching
 * algorithm based on a Boyer-Moore
@@ -14,11 +18,6 @@
 #include <ctype.h>
 #include "bits.h"
 
-//#define DEBUGBUILD
-//#define DEBUGMATCH
-//#define DEBUGFINAL
-//#define DEBUGESCAPE
-
 #ifdef DEBUGFINAL
 int		node_count=0;
 #endif
@@ -35,9 +34,7 @@ extern GlobalVars	Globals;
 **************************************/
 int InitJTree(JTree* j, char NoCase){
 	
-#ifdef DEBUGPATH
-	printf("In InitJTree\n");
-#endif	
+  DEBUGPATH;
 
 	bzero(j, sizeof(JTree));
 	
@@ -53,9 +50,7 @@ int AddStringJTreeReal(JTree* j, unsigned char* String, int SLen, int RuleID){
 	JNode*	node;
 	int		i;
 
-#ifdef DEBUGPATH
-	printf("In AddStringJTree\n");
-#endif
+	DEBUGPATH;
 
 	if (!j) return FALSE;
 	if (!String) return FALSE;
@@ -131,9 +126,7 @@ int AddStringJTree(JTree* j, unsigned char* String, int SLen, int RuleID){
 	char			BinBuff[6];
 	int				BinChar;
 	
-#ifdef DEBUGPATH
-	printf("In AddStringJTree\n");
-#endif
+	DEBUGPATH;
 
 	/*apply the escape decoding*/
 	IsBinary=FALSE;
@@ -217,9 +210,7 @@ JNode* FindOptimalNode(JTree* j, JNode*	n, unsigned char*	String, int SLen){
 	JNode*			optimal;
 	JNode*			node;
 	
-#ifdef DEBUGPATH
-	printf("In FindOptimalNode\n");
-#endif
+	DEBUGPATH;
 
 #ifdef DEBUGFINAL
 	printf("Finding optimial node for %s\n",String);
@@ -302,9 +293,7 @@ int ConvertNode(JNode* n, JNode** Parent, int NoCase){
 	static int		SCount=0;
 	static int		LCount=0;
 	
-#ifdef DEBUGPATH
-	printf("In CompressJTree\n");
-#endif
+	DEBUGPATH;
 
 	printf("This node has %i subnodes \"%c\"\n",n->Count,n->temp);
 
@@ -379,9 +368,7 @@ int FreeNode(JNode* n){
 ******************************************/
 int CompressJTree(JTree* j){
 
-#ifdef DEBUGPATH
-	printf("In CompressJTree\n");
-#endif
+  DEBUGPATH;
 
 	return ConvertNode(j->Head, NULL, j->NoCase);
 }
@@ -390,16 +377,14 @@ int CompressJTree(JTree* j){
 * Fill in the FailNode 
 * entries
 *******************************************/
-int FinalizeJTree(JTree* j){
+int FinalizeJTree(JTree* j) {
 	
-#ifdef DEBUGPATH
-	printf("In FinalizeJTree\n");
-#endif
+  DEBUGPATH;
 
 	if (!j) return FALSE;
-	if (!j->Head){
-		printf("Tree is empty\n");
-		return FALSE;
+	if (!j->Head) {
+	  DBG( PRINT("Tree is empty\n") );
+	  return FALSE;
 	}
 
 #ifdef DEBUGFINAL
@@ -428,9 +413,7 @@ int MatchStrings(JTree* j, unsigned char* PacketRuleBits, unsigned char* String,
 	int				i;
 	unsigned char	LocalDepend[MAX_RULES/8];
 	
-#ifdef DEBUGPATH
-	printf("In MatchStrings\n");
-#endif
+	DEBUGPATH;
 
 	memcpy(LocalDepend, j->DependMask, MAX_RULES/8);
 
@@ -452,15 +435,10 @@ int MatchStrings(JTree* j, unsigned char* PacketRuleBits, unsigned char* String,
 				SetBit(LocalDepend, Globals.NumRules, node->TerminalRuleID, 0);
 			}
 		}else{
+			node=node->FailNode;
 
-		  // original code! including Boyer moore optimization:
-		        //node=node->FailNode;
-                        //if (node!=j->Head) i--;
-
-		        node=j->Head;
-                        if(node->Bytes[String[i]]) i--;
-
-
+			if (node!=j->Head)
+				i--;
 		}
 	}
 
