@@ -197,10 +197,10 @@ int WritePacketLinuxRaw(int InterfaceID, unsigned char* Packet, int PacketLen){
 	interface=&Globals.Interfaces[InterfaceID];
 	
 	count=write(interface->FD, Packet, PacketLen);
-	if (count==-1){
+/*	if (count==-1){
 		printf("Failed to write packet to interface %s\n",interface->Name);
 		return FALSE;
-	}
+	} */
 	
 	return TRUE;
 }
