@@ -28,6 +28,10 @@
 #include "test_tcp_flags.h"
 #include "test_tcp_offset.h"
 #include "test_tcp_regex.h"
+#include "test_http_content.h"
+#include "test_http_method.h"
+#include "test_http_nocase.h"
+#include "test_http_regex.h"
 #include "test_udp_regex.h"
 #include "test_udp_src.h"
 #include "test_udp_dst.h"
@@ -44,9 +48,8 @@ extern GlobalVars	Globals;
 * Add all the tests to the tree
 *******************************/
 int InitTests(){
-#ifdef DEBUGPATH
-	printf("In InitTests\n");
-#endif
+
+	DEBUGPATH;
 
 	if (!InitTestInterfaceName()) return FALSE;
 	if (!InitTestEthernetType()) return FALSE;
@@ -68,7 +71,11 @@ int InitTests(){
 	if (!InitTestTCPFlags()) return FALSE;	
 	if (!InitTestTCPOffset()) return FALSE;
 	if (!InitTestTCPRegExp()) return FALSE;
-        if (!InitTestUDPRegExp()) return FALSE;
+	if (!InitTestHTTPContent()) return FALSE;
+	if (!InitTestHTTPMethod()) return FALSE;
+	if (!InitTestHTTPNoCase()) return FALSE;
+	if (!InitTestHTTPRegExp()) return FALSE;
+	if (!InitTestUDPRegExp()) return FALSE;
 	if (!InitTestUDPSrc()) return FALSE;
 	if (!InitTestUDPDst()) return FALSE;
 //	if (!InitTestDNSNumQ()) return FALSE;
@@ -84,9 +91,7 @@ int InitTests(){
 int	GetTestByName(char* Name){
 	int	i;
 
-#ifdef DEBUGPATH
-	printf("In GetTestByName\n");
-#endif
+	DEBUGPATH;
 
 	for (i=0;i<Globals.NumTests;i++)
 		if (strcasecmp(Name, Globals.Tests[i].Name)==0) return i;
@@ -99,10 +104,8 @@ int	GetTestByName(char* Name){
 **************************************/
 int CreateTest(char* Name){
 	int		TestID;
-	
-#ifdef DEBUGPATH
-	printf("In CreateTest\n");
-#endif	
+
+	DEBUGPATH;
 
 	
 	TestID=GetTestByName(Name);
@@ -110,13 +113,13 @@ int CreateTest(char* Name){
 		printf("There is already a test named %s\n",Name);
 		return TEST_NONE;
 	}
-	
+
 	TestID=Globals.NumTests;
 	Globals.NumTests++;
-	
+
 	snprintf(Globals.Tests[TestID].Name, MAX_NAME_LEN, "%s", Name);
 	Globals.Tests[TestID].ID=TestID;
-	
+
 #ifdef DEBUG
 	printf("Allocating test \"%s\" in number %i\n",Globals.Tests[TestID].Name, TestID);	
 #endif	
@@ -129,10 +132,8 @@ int CreateTest(char* Name){
 **************************************************/
 int BindTestToDecoder(int TestID, char* Decoder){
 	int DecoderID;
-	
-#ifdef DEBUGPATH
-	printf("In BindTestToDecoder\n");
-#endif
+
+	DEBUGPATH;
 
 	DecoderID=GetDecoderByName(Decoder);
 	Globals.Tests[TestID].DecoderID=DecoderID;
@@ -147,12 +148,11 @@ int BindTestToDecoder(int TestID, char* Decoder){
 * Used for fast pruning
 ****************************************************/
 int TestSetDependency(int TestID, int RuleID){
-#ifdef DEBUGPATH
-	printf("In TestSetDependency\n");
-#endif
-	
+
+	DEBUGPATH;
+
 	if (TestID > Globals.NumTests) return FALSE;
-	
+
 	SetBit(Globals.Tests[TestID].DependencyMask, Globals.NumRules, RuleID, 1);
 
 	return TRUE;
@@ -167,14 +167,12 @@ int TestAddNode(int TestID, int RuleNum, void* Data){
 	TestNode*	New;
 	DecoderRec*	Decoder;
 
-#ifdef DEBUGPATH
-	printf("In TestAddNode\n");
-#endif	
-	
+	DEBUGPATH;
+
 	New=(TestNode*)calloc(sizeof(TestNode),1);
 	New->RuleID=RuleNum;
 	New->Data=Data;
-	
+
 	if (!Globals.Tests[TestID].TestNodes){
 		Globals.Tests[TestID].TestNodes=New;
 	}else{
@@ -182,14 +180,14 @@ int TestAddNode(int TestID, int RuleNum, void* Data){
 		while (Node->Next) Node=Node->Next;
 		Node->Next=New;
 	}	
-	
+
 	/*mark the test and decoder as active*/
 #ifdef DEBUG
 	printf("Marking test \"%s\" as active\n",Globals.Tests[TestID].Name);
 #endif	
 	Globals.Tests[TestID].Active=TRUE;
 	TestSetDependency(TestID, RuleNum);
-	
+
 	Decoder=&Globals.Decoders[Globals.Tests[TestID].DecoderID];
 	while (Decoder){
 #ifdef DEBUG
@@ -199,7 +197,7 @@ int TestAddNode(int TestID, int RuleNum, void* Data){
 		DecoderSetDependency(Decoder->ID, RuleNum);
 		Decoder=Decoder->Parent;
 	}
-		
+
 	return TRUE;
 }
 
@@ -209,14 +207,12 @@ int TestAddNode(int TestID, int RuleNum, void* Data){
 **********************************/
 int TestsFinishSetup(){
 	int	i;
-	
-#ifdef DEBUGPATH
-	printf("In TestsFinishSetup\n");
-#endif
+
+	DEBUGPATH;
 
 	for (i=0;i<Globals.NumTests;i++){
 		if (Globals.Tests[i].FinishedSetup) Globals.Tests[i].FinishedSetup();
 	}
-	
+
 	return TRUE;
 }
